package main

import (
	"faiss-client-go/faiss"
	"flag"
	"fmt"
	"strconv"
	"strings"
	"time"

	pb "faiss-client-go/faiss/pai_web"

	"log"
)

var (
	host      *string
	vectorstr *string
	k         *int
)

func init() {
	host = flag.String("host", "", "faiss server address")
	vectorstr = flag.String("vector", "", "request vector data")
	k = flag.Int("k", 10, "request topn size")
}
func main() {
	flag.Parse()
	client, err := faiss.NewVectorClient(*host, 1*time.Second)
	if err != nil {
		log.Fatal(err)
		return
	}

	vectors := strings.Split(*vectorstr, " ")
	vector := make([]float32, 0)
	for _, vc := range vectors {
		if !strings.Contains(vc, ":") {
			continue
		}
		vals := strings.Split(vc, ":")
		if len(vals) == 2 {
			value, _ := strconv.ParseFloat(vals[1], 32)
			vector = append(vector, float32(value))
		}
	}

	request := pb.VectorRequest{
		K:      uint32(*k),
		Vector: vector,
	}

	response, err := client.Search(&request)
	if err != nil {
		log.Fatal(err)
		return
	}

	// 打印label，就是 svm 里的 tag， 场景中的 itemid
	for _, l := range response.Labels {
		fmt.Print(l, " ")
	}
	fmt.Println(" ")

	// 打印分数
	for _, s := range response.Scores {
		fmt.Print(s, " ")
	}
	fmt.Println(" ")

	// 打印索引位置
	for _, i := range response.Retval {
		fmt.Print(i, " ")
	}
	fmt.Println(" ")
}
